@@ -1,7 +1,7 @@
 <?php
 require("config.php");
 
-define(PB_ENTRY_MAX_LENGTH, 20);
+define("PB_ENTRY_MAX_LENGTH", 20);
 
 function GS_escape($string) {
 	global $gs_charset;
@@ -23,7 +23,9 @@ function get_GSPhonebook() {
 					(SELECT id from users WHERE gshostname = '%s'))",
 					pg_escape_string($_SERVER['REMOTE_ADDR']));
 	$result = pg_query($query);
+#print $query;
 	$result = pg_fetch_all($result);
+#print_r($result);
 	$output = "<?xml version=\"1.0\" encoding=\"$gs_charset\"?>\n<AddressBook>\n";
 	if($result)
 		foreach($result as $row) {
