@@ -7,6 +7,8 @@ function get_logininfo() {
 			$_SESSION['ext'],
 			$_SESSION['phone'],
 			$_SESSION['gshostname']);
+	if($_SESSION['phone'] == "Unidata")
+		$html = $html . "<br/><a href='pbookupload.php' target='_blank'>" . _("Upload phonebook to phone") . "</a>";
 	return $html;
 }
 
@@ -25,10 +27,12 @@ echo '<?xml version="1.0" encoding="UTF-8"?>'
 	</head> 
 	<body> 
 		<div id='logininfo' class='logininfo'><?=get_logininfo()?></div>
-		<h1><?=_("GS/* phonebook + WebBLF")?> v0.7b</h1>
+		<div id='quickdial' class='quickdial'></div>
+		<h1><?=_("GS/* phonebook + WebBLF")?> v0.8</h1>
 		<ul class="menu" id='menu'>
 			<!--<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="searchFunc(document.getElementById('searchbox').value);"/></li>-->
-			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/><a href="javascript:return false;"><img class="clear" src="images/clear.png" alt="<?=_("Clear searchbox")?>" title="<?=_("Clear searchbox")?>" onClick="document.getElementById('searchbox').value='';OnKeyRequestBuffer.modified('searchbox');"></a></li>
+			<li><?=_("Search")?>: <input type="text" name="searchbox" id="searchbox" size="20" onkeyup="OnKeyRequestBuffer.modified('searchbox');"/><img class="clear" src="images/clear.png" alt="<?=_("Clear searchbox")?>" title="<?=_("Clear searchbox")?>" onClick="document.getElementById('searchbox').value='';OnKeyRequestBuffer.modified('searchbox');"></li>
+			<li><?=_("Dial")?>: <input type="text" name="dial" id="dialbox" size="17" onkeypress="return dial_on_enter(this, event);"/><img class="dialb" src="images/dialb.png" alt="<?=_("Dial")?>" title="<?=_("Dial")?>" onClick="xajax_dial(xajax.$('dialbox').value)" /><img class="clear" src="images/clear.png" alt="<?=_("Clear dialbox")?>" title="<?=_("Clear dialbox")?>" onClick="document.getElementById('dialbox').value='';"></li>
 			<li><a href="#" onclick="setSearchType('phonebook');xajax_pb_search('');return false;"><?=_("Phonebook")?></a></li>
 			<li><a href="#" onclick="setSearchType('history');xajax_history_search('');return false;"><?=_("Call history")?></a></li>
 			<li><a href="#" onclick="setSearchType('off');xajax_up_display('');return false;"><?=_("Preferences")?></a></li>
