@@ -1,7 +1,7 @@
 <?php
 require("config.php");
 
-function get_config_value($uid, $key) {
+function get_config_value($uid, $key, $default = '') {
 	$uid = (int)$uid;
 	$key = pg_escape_string($key);
 	if($uid)
@@ -10,7 +10,10 @@ function get_config_value($uid, $key) {
 		$query = "SELECT value FROM config WHERE uid IS NULL and key = '$key'";
 	$result = pg_query($query);
 
-	return pg_fetch_result($result, 'value');
+	$value = pg_fetch_result($result, 'value');
+	if(!$value)
+		return $default;
+	return $value;
 }
 
 /* Session setup */
