@@ -24,6 +24,7 @@ class listobj {
 	function editEntry($id) {
 		$objResponse = new xajaxResponse();
 		$objResponse->script("remove_children('row$id')");
+		//$objResponse->assign("row$id", "innerHTML", $this->get_editEntry($id));
 		$this->assign_editEntry($objResponse, $id);
 		$objResponse->script("document.getElementById('" . $this->focus . "').focus()");
 		return $objResponse;
@@ -86,7 +87,7 @@ class listobj {
 			$i = 0;
 			foreach($result as $row) {
 				$html .= sprintf("<tr id='row%s' class='%s'>%s</tr>\n",
-						$row['id'],
+						isset($row['id']) ? $row['id'] : '',
 						($i % 2) ? 'odd':'even',
 						$this->html_row($row));
 				$i++;
@@ -117,7 +118,9 @@ class listobj {
 		} else
 			$entry = array();
 
+		//$objResponse->assign("row$id", "innerHTML", $this->get_editEntry($id));
 		$this->assign_html_editEntry($objResponse, $id, $entry);
+		//return $this->html_editEntry($entry);
 	}
 
 }
