@@ -38,6 +38,8 @@ class phonebook extends listobj {
 	}
 
 	function assign_html_editEntry($objResponse, $id, $entry) {
+		if(!$entry)
+			$entry = array('id' => 0, 'lastname' => '', 'firstname' => '', 'info' => '', 'phonenumber' => '', 'accountindex' => 0, 'extrafields' => '', 'gid' => '');
 		$id = (int)$entry['id'];
 		$span = 6 + sizeof($this->extrafields);
 		$html  = "<form id='editform$id' name='editform' action='#' onsubmit='xajax_" . $this->prefix . "_saveEntry(xajax.getFormValues(\"editform$id\")); return false'>\n";
@@ -66,7 +68,7 @@ class phonebook extends listobj {
 		$extras = explode("&", $entry['extrafields']);
 		for($i = 0; $i < sizeof($this->extrafields); $i++) {
 			$key = $this->extrafields[$i];
-			$val = urldecode($extras[$i]);
+			$val = urldecode(isset($extras[$i]) ? $extras[$i] : '');
 			$html .= "<div class='editlabel'>$key:</div>";
 			$html .= "<input class='editextra' type='text' name='extra[]' value='$val'/><br/>\n";
 		}
@@ -110,11 +112,11 @@ class phonebook extends listobj {
 			$html .= sprintf("<td>%s</td>", $row['accountindex'] + 1);
 
 		if(!isset($row['extrafields']))		# Saved entry
-			$extras = (array)$row['extra'];
+			$extras = array_key_exists('extra', $row) ? (array)$row['extra'] : array();
 		else
 			$extras = explode("&", $row['extrafields']);
 		for($i = 0; $i < sizeof($this->extrafields); $i++) {
-			$html .= sprintf("<td>%s</td>", urldecode($extras[$i]));
+			$html .= sprintf("<td>%s</td>", array_key_exists($i, $extras) ? urldecode($extras[$i]) : "");
 		}
 
 		$html .= sprintf("<td>%s</td>", $row['groupname']);
