@@ -13,7 +13,7 @@ $now = time();
 $end = max($now + 2, $now + $max_execution_time - 2);
 
 while(time() < $end) {
-	$result = pg_query("SELECT value from state WHERE value > '$last_update'");
+	$result = pg_query("SELECT value from state WHERE key = 'last_update' AND value > '$last_update'");
 	if(pg_num_rows($result)) {
 		echo 1;
 		exit;
